@@ -174,7 +174,13 @@ class Connection(object):
         self._client.cancelQuery(queryId=query_id)
 
     def get_tables(self, database):
-        self._client.getTables(schema=database)
+        return self._client.getTables(schema=database)
+
+    def getTables(self, database):
+        return self.get_tables(database)
+
+    def get_columns(self, database, table):
+        return self._client.getColumns(schema=database, table=table)
 
     def commit(self):
         """Hive does not support transactions, so this does nothing."""
@@ -275,9 +281,13 @@ class Cursor(DBAPICursor):
         self._rowcount = None
         pass
 
-    def getTables(self):
+    def get_tables(self):
         schema = self.connection.database
-        self.connection.get_tables(database=schema)
+        return self.connection.get_tables(database=schema)
+
+    def get_columns(self, table):
+        schema = self.connection.database
+        return self.connection.get_columns(database=schema, table=table)
 
     def clear(self):
         """Clears the tmp data"""
